/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <qapp_macro.h>

QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <iterator>

// module include
#include "pyside2_qt3danimation_python.h"

// main header
#include "qt3danimation_qanimationcontroller_wrapper.h"

// inner classes

// Extra includes
#include <QList>
#include <QVector>
#include <Qt3DAnimation/qanimationgroup.h>
#include <Qt3DCore/qentity.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


#include <cctype>
#include <cstring>
using namespace Qt3DAnimation;



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QAnimationControllerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAnimationControllerWrapper::QAnimationControllerWrapper(QObject * parent) : Qt3DAnimation::QAnimationController(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QAnimationControllerWrapper::childEvent(QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        this->::QObject::childEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[0] = true;
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QAnimationControllerWrapper::connectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        this->::QObject::connectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[1] = true;
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QAnimationControllerWrapper::customEvent(QEvent * event)
{
    if (m_PyMethodCache[2]) {
        this->::QObject::customEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[2] = true;
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QAnimationControllerWrapper::disconnectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        this->::QObject::disconnectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[3] = true;
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QAnimationControllerWrapper::event(QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[4] = true;
        return this->::QObject::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAnimationController.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QAnimationControllerWrapper::eventFilter(QObject * watched, QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[5] = true;
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAnimationController.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QAnimationControllerWrapper::timerEvent(QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        this->::QObject::timerEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[7] = true;
        this->::QObject::timerEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QAnimationControllerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DAnimation::QAnimationController::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAnimationControllerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DAnimation::QAnimationController::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAnimationControllerWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QAnimationControllerWrapper *>(this));
        return Qt3DAnimation::QAnimationController::qt_metacast(_clname);
}

QAnimationControllerWrapper::~QAnimationControllerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DAnimation_QAnimationController_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DAnimation::QAnimationController >()))
        return -1;

    ::QAnimationControllerWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAnimationController", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QAnimationController::QAnimationController(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QAnimationController(QObject*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAnimationController(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationController_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","parent");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController(): got multiple values for keyword argument 'parent'.");
                    return -1;
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                        goto Sbk_Qt3DAnimation_QAnimationController_Init_TypeError;
                }
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QAnimationController(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr) {
                cptr = new (addr) ::QAnimationControllerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(0);
            } else {
                cptr = new ::QAnimationControllerWrapper(cppArg0);
            }

            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DAnimation::QAnimationController >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Qt3DAnimation_QAnimationController_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_Qt3DAnimation_QAnimationController_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController");
        return -1;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_activeAnimationGroup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // activeAnimationGroup()const
            int cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->activeAnimationGroup();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_addAnimationGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::addAnimationGroup(Qt3DAnimation::QAnimationGroup*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]), (pyArg)))) {
        overloadId = 0; // addAnimationGroup(Qt3DAnimation::QAnimationGroup*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_addAnimationGroup_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAnimationGroup *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // addAnimationGroup(Qt3DAnimation::QAnimationGroup*)
            cppSelf->addAnimationGroup(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_addAnimationGroup_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.addAnimationGroup");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_animationGroupList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // animationGroupList()
            QVector<Qt3DAnimation::QAnimationGroup* > cppResult = cppSelf->animationGroupList();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_Qt3DAnimationTypeConverters[SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QANIMATIONGROUPPTR_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_entity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // entity()const
            Qt3DCore::QEntity * cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->entity();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_getAnimationIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::getAnimationIndex(QString)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // getAnimationIndex(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_getAnimationIndex_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // getAnimationIndex(QString)const
            int cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->getAnimationIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_getAnimationIndex_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.getAnimationIndex");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_getGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::getGroup(int)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // getGroup(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_getGroup_TypeError;

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // getGroup(int)const
            Qt3DAnimation::QAnimationGroup * cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->getGroup(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_getGroup_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.getGroup");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // position()const
            float cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->position();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_positionOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // positionOffset()const
            float cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->positionOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_positionScale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // positionScale()const
            float cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->positionScale();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_recursive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // recursive()const
            bool cppResult = const_cast<const ::Qt3DAnimation::QAnimationController *>(cppSelf)->recursive();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_removeAnimationGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::removeAnimationGroup(Qt3DAnimation::QAnimationGroup*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]), (pyArg)))) {
        overloadId = 0; // removeAnimationGroup(Qt3DAnimation::QAnimationGroup*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_removeAnimationGroup_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DAnimation::QAnimationGroup *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // removeAnimationGroup(Qt3DAnimation::QAnimationGroup*)
            cppSelf->removeAnimationGroup(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_removeAnimationGroup_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.removeAnimationGroup");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setActiveAnimationGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setActiveAnimationGroup(int)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setActiveAnimationGroup(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setActiveAnimationGroup_TypeError;

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setActiveAnimationGroup(int)
            cppSelf->setActiveAnimationGroup(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setActiveAnimationGroup_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setActiveAnimationGroup");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setAnimationGroups(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setAnimationGroups(QVector<Qt3DAnimation::QAnimationGroup*>)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_Qt3DAnimationTypeConverters[SBK_QT3DANIMATION_QVECTOR_QT3DANIMATION_QANIMATIONGROUPPTR_IDX], (pyArg)))) {
        overloadId = 0; // setAnimationGroups(QVector<Qt3DAnimation::QAnimationGroup*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setAnimationGroups_TypeError;

    // Call function/method
    {
        ::QVector<Qt3DAnimation::QAnimationGroup* > cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setAnimationGroups(QVector<Qt3DAnimation::QAnimationGroup*>)
            cppSelf->setAnimationGroups(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setAnimationGroups_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setAnimationGroups");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setEntity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setEntity(Qt3DCore::QEntity*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QENTITY_IDX]), (pyArg)))) {
        overloadId = 0; // setEntity(Qt3DCore::QEntity*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setEntity_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DCore::QEntity *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setEntity(Qt3DCore::QEntity*)
            cppSelf->setEntity(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setEntity_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setEntity");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setPosition(float)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setPosition(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setPosition_TypeError;

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPosition(float)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setPosition_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPosition");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setPositionOffset(float)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setPositionOffset(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionOffset_TypeError;

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPositionOffset(float)
            cppSelf->setPositionOffset(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionOffset_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPositionOffset");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setPositionScale(float)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setPositionScale(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionScale_TypeError;

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPositionScale(float)
            cppSelf->setPositionScale(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionScale_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPositionScale");
        return {};
}

static PyObject *Sbk_Qt3DAnimation_QAnimationControllerFunc_setRecursive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAnimationController::setRecursive(bool)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRecursive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DAnimation_QAnimationControllerFunc_setRecursive_TypeError;

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setRecursive(bool)
            cppSelf->setRecursive(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DAnimation_QAnimationControllerFunc_setRecursive_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setRecursive");
        return {};
}

static PyMethodDef Sbk_Qt3DAnimation_QAnimationController_methods[] = {
    {"activeAnimationGroup", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_activeAnimationGroup), METH_NOARGS},
    {"addAnimationGroup", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_addAnimationGroup), METH_O},
    {"animationGroupList", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_animationGroupList), METH_NOARGS},
    {"entity", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_entity), METH_NOARGS},
    {"getAnimationIndex", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_getAnimationIndex), METH_O},
    {"getGroup", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_getGroup), METH_O},
    {"position", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_position), METH_NOARGS},
    {"positionOffset", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_positionOffset), METH_NOARGS},
    {"positionScale", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_positionScale), METH_NOARGS},
    {"recursive", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_recursive), METH_NOARGS},
    {"removeAnimationGroup", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_removeAnimationGroup), METH_O},
    {"setActiveAnimationGroup", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setActiveAnimationGroup), METH_O},
    {"setAnimationGroups", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setAnimationGroups), METH_O},
    {"setEntity", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setEntity), METH_O},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setPosition), METH_O},
    {"setPositionOffset", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionOffset), METH_O},
    {"setPositionScale", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setPositionScale), METH_O},
    {"setRecursive", reinterpret_cast<PyCFunction>(Sbk_Qt3DAnimation_QAnimationControllerFunc_setRecursive), METH_O},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_Qt3DAnimation_QAnimationController_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::Qt3DAnimation::QAnimationController *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QAnimationControllerWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DAnimation_QAnimationController_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_Qt3DAnimation_QAnimationController_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_Qt3DAnimation_QAnimationController_Type = nullptr;
static SbkObjectType *Sbk_Qt3DAnimation_QAnimationController_TypeF(void)
{
    return _Sbk_Qt3DAnimation_QAnimationController_Type;
}

static PyType_Slot Sbk_Qt3DAnimation_QAnimationController_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationController_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationController_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationController_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationController_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DAnimation_QAnimationController_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DAnimation_QAnimationController_spec = {
    "2:PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DAnimation_QAnimationController_slots
};

} //extern "C"

static void *Sbk_Qt3DAnimation_QAnimationController_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::Qt3DAnimation::QAnimationController *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAnimationController_PythonToCpp_QAnimationController_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DAnimation_QAnimationController_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAnimationController_PythonToCpp_QAnimationController_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_Qt3DAnimation_QAnimationController_TypeF())))
        return QAnimationController_PythonToCpp_QAnimationController_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAnimationController_PTR_CppToPython_QAnimationController(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DAnimation::QAnimationController *>(const_cast<void *>(cppIn)), Sbk_Qt3DAnimation_QAnimationController_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DAnimation_QAnimationController_SignatureStrings[] = {
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController(parent:PySide2.QtCore.QObject=nullptr))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.activeAnimationGroup()->int)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.addAnimationGroup(animationGroups:PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationGroup))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.animationGroupList()->QVector[PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationGroup])CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.entity()->PySide2.Qt3DCore.Qt3DCore.QEntity)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.getAnimationIndex(name:QString)->int)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.getGroup(index:int)->PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationGroup)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.position()->float)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.positionOffset()->float)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.positionScale()->float)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.recursive()->bool)CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.removeAnimationGroup(animationGroups:PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationGroup))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setActiveAnimationGroup(index:int))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setAnimationGroups(animationGroups:QVector[PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationGroup]))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setEntity(entity:PySide2.Qt3DCore.Qt3DCore.QEntity))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPosition(position:float))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPositionOffset(offset:float))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setPositionScale(scale:float))CPP",
    R"CPP(PySide2.Qt3DAnimation.Qt3DAnimation.QAnimationController.setRecursive(recursive:bool))CPP",
    nullptr}; // Sentinel

void init_Qt3DAnimation_QAnimationController(PyObject *enclosingClass)
{
    _Sbk_Qt3DAnimation_QAnimationController_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QAnimationController",
        "Qt3DAnimation::QAnimationController*",
        &Sbk_Qt3DAnimation_QAnimationController_spec,
        Qt3DAnimation_QAnimationController_SignatureStrings,
        &Shiboken::callCppDestructor< ::Qt3DAnimation::QAnimationController >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass    );
    
    SbkPySide2_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_Qt3DAnimation_QAnimationController_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_Qt3DAnimation_QAnimationController_TypeF(),
        QAnimationController_PythonToCpp_QAnimationController_PTR,
        is_QAnimationController_PythonToCpp_QAnimationController_PTR_Convertible,
        QAnimationController_PTR_CppToPython_QAnimationController);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationController");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationController*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DAnimation::QAnimationController&");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationController");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationController*");
    Shiboken::Conversions::registerConverterName(converter, "QAnimationController&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DAnimation::QAnimationController).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAnimationControllerWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_Qt3DAnimation_QAnimationController_TypeF(), &Sbk_Qt3DAnimation_QAnimationController_typeDiscovery);

    PySide::Signal::registerSignals(Sbk_Qt3DAnimation_QAnimationController_TypeF(), &::Qt3DAnimation::QAnimationController::staticMetaObject);

    Shiboken::ObjectType::setSubTypeInitHook(Sbk_Qt3DAnimation_QAnimationController_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_Qt3DAnimation_QAnimationController_TypeF(), &::Qt3DAnimation::QAnimationController::staticMetaObject, sizeof(QAnimationControllerWrapper));
}
