/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <qapp_macro.h>

QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <iterator>

// module include
#include "pyside2_qt3dinput_python.h"

// main header
#include "qt3dinput_qmousedevice_wrapper.h"

// inner classes

// Extra includes
#include <QVector>
#include <Qt3DCore/qnode.h>
#include <Qt3DInput/qaxissetting.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>


#include <cctype>
#include <cstring>
using namespace Qt3DInput;



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QMouseDeviceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QMouseDeviceWrapper::QMouseDeviceWrapper(Qt3DCore::QNode * parent) : Qt3DInput::QMouseDevice(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QMouseDeviceWrapper::childEvent(QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        this->::QObject::childEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[0] = true;
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QMouseDeviceWrapper::connectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        this->::QObject::connectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[1] = true;
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QMouseDeviceWrapper::customEvent(QEvent * event)
{
    if (m_PyMethodCache[2]) {
        this->::QObject::customEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[2] = true;
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QMouseDeviceWrapper::disconnectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        this->::QObject::disconnectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[3] = true;
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QMouseDeviceWrapper::event(QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[4] = true;
        return this->::QObject::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QMouseDevice.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QMouseDeviceWrapper::eventFilter(QObject * watched, QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[5] = true;
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QMouseDevice.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QMouseDeviceWrapper::timerEvent(QTimerEvent * event)
{
    if (m_PyMethodCache[7]) {
        this->::QObject::timerEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[7] = true;
        this->::QObject::timerEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QMouseDeviceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DInput::QMouseDevice::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QMouseDeviceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DInput::QMouseDevice::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QMouseDeviceWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QMouseDeviceWrapper *>(this));
        return Qt3DInput::QMouseDevice::qt_metacast(_clname);
}

QMouseDeviceWrapper::~QMouseDeviceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DInput_QMouseDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DInput::QMouseDevice >()))
        return -1;

    ::QMouseDeviceWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QMouseDevice", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QMouseDevice::QMouseDevice(Qt3DCore::QNode*)
    if (numArgs == 0) {
        overloadId = 0; // QMouseDevice(Qt3DCore::QNode*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QMouseDevice(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DInput_QMouseDevice_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","parent");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice(): got multiple values for keyword argument 'parent'.");
                    return -1;
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QNODE_IDX]), (pyArgs[0]))))
                        goto Sbk_Qt3DInput_QMouseDevice_Init_TypeError;
                }
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QMouseDevice(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr) {
                cptr = new (addr) ::QMouseDeviceWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(0);
            } else {
                cptr = new ::QMouseDeviceWrapper(cppArg0);
            }

            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Qt3DInput::QMouseDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Qt3DInput_QMouseDevice_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_Qt3DInput_QMouseDevice_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice");
        return -1;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_axisCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // axisCount()const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::axisCount() : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->axisCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_axisIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::axisIdentifier(QString)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // axisIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DInput_QMouseDeviceFunc_axisIdentifier_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // axisIdentifier(QString)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::axisIdentifier(cppArg0) : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->axisIdentifier(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Qt3DInput_QMouseDeviceFunc_axisIdentifier_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice.axisIdentifier");
        return {};
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_axisNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // axisNames()const
            QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::axisNames() : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->axisNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_buttonCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // buttonCount()const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::buttonCount() : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->buttonCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_buttonIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractPhysicalDevice::buttonIdentifier(QString)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArg)))) {
        overloadId = 0; // buttonIdentifier(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DInput_QMouseDeviceFunc_buttonIdentifier_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // buttonIdentifier(QString)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::buttonIdentifier(cppArg0) : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->buttonIdentifier(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Qt3DInput_QMouseDeviceFunc_buttonIdentifier_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice.buttonIdentifier");
        return {};
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_buttonNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // buttonNames()const
            QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->::Qt3DInput::QMouseDevice::buttonNames() : const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->buttonNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide2_QtCoreTypeConverters[SBK_QSTRINGLIST_IDX], &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_sensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // sensitivity()const
            float cppResult = const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->sensitivity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_setSensitivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMouseDevice::setSensitivity(float)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setSensitivity(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DInput_QMouseDeviceFunc_setSensitivity_TypeError;

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setSensitivity(float)
            cppSelf->setSensitivity(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DInput_QMouseDeviceFunc_setSensitivity_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice.setSensitivity");
        return {};
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_setUpdateAxesContinuously(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMouseDevice::setUpdateAxesContinuously(bool)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUpdateAxesContinuously(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Qt3DInput_QMouseDeviceFunc_setUpdateAxesContinuously_TypeError;

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setUpdateAxesContinuously(bool)
            cppSelf->setUpdateAxesContinuously(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Qt3DInput_QMouseDeviceFunc_setUpdateAxesContinuously_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.Qt3DInput.Qt3DInput.QMouseDevice.setUpdateAxesContinuously");
        return {};
}

static PyObject *Sbk_Qt3DInput_QMouseDeviceFunc_updateAxesContinuously(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // updateAxesContinuously()const
            bool cppResult = const_cast<const ::Qt3DInput::QMouseDevice *>(cppSelf)->updateAxesContinuously();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_Qt3DInput_QMouseDevice_methods[] = {
    {"axisCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_axisCount), METH_NOARGS},
    {"axisIdentifier", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_axisIdentifier), METH_O},
    {"axisNames", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_axisNames), METH_NOARGS},
    {"buttonCount", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_buttonCount), METH_NOARGS},
    {"buttonIdentifier", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_buttonIdentifier), METH_O},
    {"buttonNames", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_buttonNames), METH_NOARGS},
    {"sensitivity", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_sensitivity), METH_NOARGS},
    {"setSensitivity", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_setSensitivity), METH_O},
    {"setUpdateAxesContinuously", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_setUpdateAxesContinuously), METH_O},
    {"updateAxesContinuously", reinterpret_cast<PyCFunction>(Sbk_Qt3DInput_QMouseDeviceFunc_updateAxesContinuously), METH_NOARGS},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_Qt3DInput_QMouseDevice_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::Qt3DInput::QMouseDevice *>(Shiboken::Conversions::cppPointer(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QMouseDeviceWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DInput_QMouseDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_Qt3DInput_QMouseDevice_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_Qt3DInput_QMouseDevice_Type = nullptr;
static SbkObjectType *Sbk_Qt3DInput_QMouseDevice_TypeF(void)
{
    return _Sbk_Qt3DInput_QMouseDevice_Type;
}

static PyType_Slot Sbk_Qt3DInput_QMouseDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DInput_QMouseDevice_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DInput_QMouseDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DInput_QMouseDevice_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DInput_QMouseDevice_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DInput_QMouseDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DInput_QMouseDevice_spec = {
    "2:PySide2.Qt3DInput.Qt3DInput.QMouseDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DInput_QMouseDevice_slots
};

} //extern "C"

static void *Sbk_Qt3DInput_QMouseDevice_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::Qt3DInput::QMouseDevice *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Qt3DInput_QMouseDevice_Axis_PythonToCpp_Qt3DInput_QMouseDevice_Axis(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::Qt3DInput::QMouseDevice::Axis *>(cppOut) =
        static_cast<::Qt3DInput::QMouseDevice::Axis>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_Qt3DInput_QMouseDevice_Axis_PythonToCpp_Qt3DInput_QMouseDevice_Axis_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX]))
        return Qt3DInput_QMouseDevice_Axis_PythonToCpp_Qt3DInput_QMouseDevice_Axis;
    return {};
}
static PyObject *Qt3DInput_QMouseDevice_Axis_CppToPython_Qt3DInput_QMouseDevice_Axis(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DInput::QMouseDevice::Axis *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX], castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMouseDevice_PythonToCpp_QMouseDevice_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DInput_QMouseDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMouseDevice_PythonToCpp_QMouseDevice_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_Qt3DInput_QMouseDevice_TypeF())))
        return QMouseDevice_PythonToCpp_QMouseDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMouseDevice_PTR_CppToPython_QMouseDevice(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DInput::QMouseDevice *>(const_cast<void *>(cppIn)), Sbk_Qt3DInput_QMouseDevice_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DInput_QMouseDevice_SignatureStrings[] = {
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice(parent:PySide2.Qt3DCore.Qt3DCore.QNode=nullptr))CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.axisCount()->int)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.axisIdentifier(name:QString)->int)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.axisNames()->QStringList)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.buttonCount()->int)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.buttonIdentifier(name:QString)->int)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.buttonNames()->QStringList)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.sensitivity()->float)CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.setSensitivity(value:float))CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.setUpdateAxesContinuously(updateAxesContinuously:bool))CPP",
    R"CPP(PySide2.Qt3DInput.Qt3DInput.QMouseDevice.updateAxesContinuously()->bool)CPP",
    nullptr}; // Sentinel

void init_Qt3DInput_QMouseDevice(PyObject *enclosingClass)
{
    _Sbk_Qt3DInput_QMouseDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QMouseDevice",
        "Qt3DInput::QMouseDevice*",
        &Sbk_Qt3DInput_QMouseDevice_spec,
        Qt3DInput_QMouseDevice_SignatureStrings,
        &Shiboken::callCppDestructor< ::Qt3DInput::QMouseDevice >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTPHYSICALDEVICE_IDX]),
        0,
        Shiboken::ObjectType::WrapperFlags::InnerClass    );
    
    SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_Qt3DInput_QMouseDevice_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_Qt3DInput_QMouseDevice_TypeF(),
        QMouseDevice_PythonToCpp_QMouseDevice_PTR,
        is_QMouseDevice_PythonToCpp_QMouseDevice_PTR_Convertible,
        QMouseDevice_PTR_CppToPython_QMouseDevice);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QMouseDevice");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QMouseDevice*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QMouseDevice&");
    Shiboken::Conversions::registerConverterName(converter, "QMouseDevice");
    Shiboken::Conversions::registerConverterName(converter, "QMouseDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QMouseDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DInput::QMouseDevice).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMouseDeviceWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_Qt3DInput_QMouseDevice_TypeF(), &Sbk_Qt3DInput_QMouseDevice_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'Axis'.
    SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX] = Shiboken::Enum::createScopedEnum(Sbk_Qt3DInput_QMouseDevice_TypeF(),
        "Axis",
        "2:PySide2.Qt3DInput.Qt3DInput.QMouseDevice.Axis",
        "Qt3DInput::QMouseDevice::Axis");
    if (!SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX],
        Sbk_Qt3DInput_QMouseDevice_TypeF(), "X", (long) Qt3DInput::QMouseDevice::Axis::X))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX],
        Sbk_Qt3DInput_QMouseDevice_TypeF(), "Y", (long) Qt3DInput::QMouseDevice::Axis::Y))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX],
        Sbk_Qt3DInput_QMouseDevice_TypeF(), "WheelX", (long) Qt3DInput::QMouseDevice::Axis::WheelX))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX],
        Sbk_Qt3DInput_QMouseDevice_TypeF(), "WheelY", (long) Qt3DInput::QMouseDevice::Axis::WheelY))
        return;
    // Register converter for enum 'Qt3DInput::QMouseDevice::Axis'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX],
            Qt3DInput_QMouseDevice_Axis_CppToPython_Qt3DInput_QMouseDevice_Axis);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Qt3DInput_QMouseDevice_Axis_PythonToCpp_Qt3DInput_QMouseDevice_Axis,
            is_Qt3DInput_QMouseDevice_Axis_PythonToCpp_Qt3DInput_QMouseDevice_Axis_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DInput::QMouseDevice::Axis");
        Shiboken::Conversions::registerConverterName(converter, "QMouseDevice::Axis");
        Shiboken::Conversions::registerConverterName(converter, "Axis");
    }
    // End of 'Axis' enum.

    PySide::Signal::registerSignals(Sbk_Qt3DInput_QMouseDevice_TypeF(), &::Qt3DInput::QMouseDevice::staticMetaObject);

    qRegisterMetaType< ::Qt3DInput::QMouseDevice::Axis >("QMouseDevice::Axis");
    qRegisterMetaType< ::Qt3DInput::QMouseDevice::Axis >("Qt3DInput::QMouseDevice::Axis");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_Qt3DInput_QMouseDevice_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_Qt3DInput_QMouseDevice_TypeF(), &::Qt3DInput::QMouseDevice::staticMetaObject, sizeof(QMouseDeviceWrapper));
}
