/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt for Python.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <qapp_macro.h>

QT_WARNING_DISABLE_DEPRECATED

#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <iterator>

// module include
#include "pyside2_qtcore_python.h"

// main header
#include "qthread_wrapper.h"

// inner classes

// Extra includes
#include <QList>
#include <qabstracteventdispatcher.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeadlinetimer.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


#include <cctype>
#include <cstring>



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void QThreadWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QThreadWrapper::QThreadWrapper(QObject * parent) : QThread(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QThreadWrapper::childEvent(QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        this->::QObject::childEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[0] = true;
        this->::QObject::childEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QCHILDEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QThreadWrapper::connectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        this->::QObject::connectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[1] = true;
        this->::QObject::connectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QThreadWrapper::customEvent(QEvent * event)
{
    if (m_PyMethodCache[2]) {
        this->::QObject::customEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[2] = true;
        this->::QObject::customEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QThreadWrapper::disconnectNotify(const QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        this->::QObject::disconnectNotify(signal);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[3] = true;
        this->::QObject::disconnectNotify(signal);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QMETAMETHOD_IDX]), &signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

bool QThreadWrapper::event(QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QThread::event(event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[4] = true;
        return this->::QThread::event(event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QThread.event", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QThreadWrapper::eventFilter(QObject * watched, QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return false;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[5] = true;
        return this->::QObject::eventFilter(watched, event);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), watched),
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), event)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return false;
    }
    // Check return type
    PythonToCppFunc pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QThread.eventFilter", "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QThreadWrapper::run()
{
    if (m_PyMethodCache[7]) {
        this->::QThread::run();
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "run"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[7] = true;
        this->::QThread::run();
        return;
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
}

void QThreadWrapper::timerEvent(QTimerEvent * event)
{
    if (m_PyMethodCache[8]) {
        this->::QObject::timerEvent(event);
        return;
    }
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        m_PyMethodCache[8] = true;
        this->::QObject::timerEvent(event);
        return;
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTIMEREVENT_IDX]), event)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject *QThreadWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QThread::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QThreadWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QThread::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QThreadWrapper::qt_metacast(const char *_clname)
{
        if (!_clname) return {};
        SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void *>(const_cast< QThreadWrapper *>(this));
        return QThread::qt_metacast(_clname);
}

QThreadWrapper::~QThreadWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QThread_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    const char *argNames[] = {"parent"};
    const QMetaObject *metaObject;
    SbkObject *sbkSelf = reinterpret_cast<SbkObject *>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QThread >()))
        return -1;

    ::QThreadWrapper *cptr{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QThread", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QThread::QThread(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QThread(QObject*)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QThread(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThread_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","parent");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread(): got multiple values for keyword argument 'parent'.");
                    return -1;
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]), (pyArgs[0]))))
                        goto Sbk_QThread_Init_TypeError;
                }
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // QThread(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr) {
                cptr = new (addr) ::QThreadWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(0);
            } else {
                cptr = new ::QThreadWrapper(cppArg0);
            }

            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QThread >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QThread_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QThread_Init_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtCore.QThread");
        return -1;
}

static PyObject *Sbk_QThreadFunc_currentThread(PyObject *self)
{
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // currentThread()
            QThread * cppResult = ::QThread::currentThread();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX]), cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QEVENT_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_event_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QThread::event(cppArg0) : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QThreadFunc_event_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.event");
        return {};
}

static PyObject *Sbk_QThreadFunc_eventDispatcher(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // eventDispatcher()const
            QAbstractEventDispatcher * cppResult = const_cast<const ::QThread *>(cppSelf)->eventDispatcher();
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QABSTRACTEVENTDISPATCHER_IDX]), cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_exec_(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // exec()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = cppSelf->exec();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_exit(PyObject *self, PyObject *args, PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.exit(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:exit", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: QThread::exit(int)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_exit_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","retcode");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.exit(): got multiple values for keyword argument 'retcode'.");
                    return {};
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        goto Sbk_QThreadFunc_exit_TypeError;
                }
            }
        }
        int cppArg0 = 0;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // exit(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->exit(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_exit_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtCore.QThread.exit");
        return {};
}

static PyObject *Sbk_QThreadFunc_idealThreadCount(PyObject *self)
{
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // idealThreadCount()
            int cppResult = ::QThread::idealThreadCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isFinished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isFinished()const
            bool cppResult = const_cast<const ::QThread *>(cppSelf)->isFinished();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isInterruptionRequested(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isInterruptionRequested()const
            bool cppResult = const_cast<const ::QThread *>(cppSelf)->isInterruptionRequested();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_isRunning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // isRunning()const
            bool cppResult = const_cast<const ::QThread *>(cppSelf)->isRunning();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_loopLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // loopLevel()const
            int cppResult = const_cast<const ::QThread *>(cppSelf)->loopLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_msleep(PyObject *self, PyObject *pyArg)
{
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::msleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // msleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_msleep_TypeError;

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // msleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::msleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_msleep_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.msleep");
        return {};
}

static PyObject *Sbk_QThreadFunc_priority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // priority()const
            QThread::Priority cppResult = const_cast<const ::QThread *>(cppSelf)->priority();
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_quit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // quit()
            cppSelf->quit();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_requestInterruption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // requestInterruption()
            cppSelf->requestInterruption();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_run(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // run()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QThread::run() : cppSelf->run();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_setEventDispatcher(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setEventDispatcher(QAbstractEventDispatcher*)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppPointerConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QABSTRACTEVENTDISPATCHER_IDX]), (pyArg)))) {
        overloadId = 0; // setEventDispatcher(QAbstractEventDispatcher*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setEventDispatcher_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractEventDispatcher *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setEventDispatcher(QAbstractEventDispatcher*)
            cppSelf->setEventDispatcher(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setEventDispatcher_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.setEventDispatcher");
        return {};
}

static PyObject *Sbk_QThreadFunc_setPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setPriority(QThread::Priority)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX])->converter, (pyArg)))) {
        overloadId = 0; // setPriority(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setPriority_TypeError;

    // Call function/method
    {
        ::QThread::Priority cppArg0{QThread::IdlePriority};
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setPriority(QThread::Priority)
            cppSelf->setPriority(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setPriority_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.setPriority");
        return {};
}

static PyObject *Sbk_QThreadFunc_setStackSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QThread::setStackSize(uint)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setStackSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setStackSize_TypeError;

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // setStackSize(uint)
            cppSelf->setStackSize(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setStackSize_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.setStackSize");
        return {};
}

static PyObject *Sbk_QThreadFunc_setTerminationEnabled(PyObject *self, PyObject *args, PyObject *kwds)
{
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.setTerminationEnabled(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:setTerminationEnabled", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: static QThread::setTerminationEnabled(bool)
    if (numArgs == 0) {
        overloadId = 0; // setTerminationEnabled(bool)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setTerminationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setTerminationEnabled_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","enabled");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.setTerminationEnabled(): got multiple values for keyword argument 'enabled'.");
                    return {};
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        goto Sbk_QThreadFunc_setTerminationEnabled_TypeError;
                }
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // setTerminationEnabled(bool)
            ::QThread::setTerminationEnabled(cppArg0);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setTerminationEnabled_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtCore.QThread.setTerminationEnabled");
        return {};
}

static PyObject *Sbk_QThreadFunc_sleep(PyObject *self, PyObject *pyArg)
{
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::sleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // sleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_sleep_TypeError;

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // sleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::sleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_sleep_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.sleep");
        return {};
}

static PyObject *Sbk_QThreadFunc_stackSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // stackSize()const
            uint cppResult = const_cast<const ::QThread *>(cppSelf)->stackSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QThreadFunc_start(PyObject *self, PyObject *args, PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.start(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:start", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: QThread::start(QThread::Priority)
    if (numArgs == 0) {
        overloadId = 0; // start(QThread::Priority)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX])->converter, (pyArgs[0])))) {
        overloadId = 0; // start(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_start_TypeError;

    // Call function/method
    {
        if (kwds) {
            PyObject *keyName = nullptr;
            PyObject *value = nullptr;
            keyName = Py_BuildValue("s","priority");
            if (PyDict_Contains(kwds, keyName)) {
                value = PyDict_GetItem(kwds, keyName);
                if (value && pyArgs[0]) {
                    PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.start(): got multiple values for keyword argument 'priority'.");
                    return {};
                }
                if (value) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX])->converter, (pyArgs[0]))))
                        goto Sbk_QThreadFunc_start_TypeError;
                }
            }
        }
        ::QThread::Priority cppArg0 = QThread::Priority::InheritPriority;
        if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!PyErr_Occurred()) {
            // start(QThread::Priority)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->start(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_start_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtCore.QThread.start");
        return {};
}

static PyObject *Sbk_QThreadFunc_terminate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // terminate()
            cppSelf->terminate();
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QThreadFunc_usleep(PyObject *self, PyObject *pyArg)
{
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QThread::usleep(ulong)
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArg)))) {
        overloadId = 0; // usleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_usleep_TypeError;

    // Call function/method
    {
        unsigned long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // usleep(ulong)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::usleep(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_usleep_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide2.QtCore.QThread.usleep");
        return {};
}

static PyObject *Sbk_QThreadFunc_wait(PyObject *self, PyObject *args, PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto cppSelf = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr };
    SBK_UNUSED(pythonToCpp)
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.wait(): too many arguments");
        return {};
    }

    if (!PyArg_ParseTuple(args, "|O:wait", &(pyArgs[0])))
        return {};


    // Overloaded function decisor
    // 0: QThread::wait(QDeadlineTimer)
    // 1: QThread::wait(ulong)
    if (numArgs == 0) {
        overloadId = 0; // wait(QDeadlineTimer)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), (pyArgs[0])))) {
        overloadId = 1; // wait(ulong)
    } else if ((pythonToCpp[0] = Shiboken::Conversions::isPythonToCppValueConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QDEADLINETIMER_IDX]), (pyArgs[0])))) {
        overloadId = 0; // wait(QDeadlineTimer)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_wait_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // wait(QDeadlineTimer deadline)
        {
            if (kwds) {
                PyObject *keyName = nullptr;
                PyObject *value = nullptr;
                keyName = Py_BuildValue("s","deadline");
                if (PyDict_Contains(kwds, keyName)) {
                    value = PyDict_GetItem(kwds, keyName);
                    if (value && pyArgs[0]) {
                        PyErr_SetString(PyExc_TypeError, "PySide2.QtCore.QThread.wait(): got multiple values for keyword argument 'deadline'.");
                        return {};
                    }
                    if (value) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::isPythonToCppValueConvertible(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QDEADLINETIMER_IDX]), (pyArgs[0]))))
                            goto Sbk_QThreadFunc_wait_TypeError;
                    }
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDeadlineTimer cppArg0 = QDeadlineTimer(QDeadlineTimer::Forever);
            if (pythonToCpp[0]) pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // wait(QDeadlineTimer)
                bool cppResult = cppSelf->wait(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // wait(unsigned long time)
        {
            unsigned long cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!PyErr_Occurred()) {
                // wait(ulong)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_QThreadFunc_wait_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "PySide2.QtCore.QThread.wait");
        return {};
}

static PyObject *Sbk_QThreadFunc_yieldCurrentThread(PyObject *self)
{

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // yieldCurrentThread()
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QThread::yieldCurrentThread();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QThread_methods[] = {
    {"currentThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_currentThread), METH_NOARGS|METH_STATIC},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_event), METH_O},
    {"eventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_eventDispatcher), METH_NOARGS},
    {"exec_", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_exec_), METH_NOARGS},
    {"exit", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_exit), METH_VARARGS|METH_KEYWORDS},
    {"idealThreadCount", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_idealThreadCount), METH_NOARGS|METH_STATIC},
    {"isFinished", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isFinished), METH_NOARGS},
    {"isInterruptionRequested", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isInterruptionRequested), METH_NOARGS},
    {"isRunning", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_isRunning), METH_NOARGS},
    {"loopLevel", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_loopLevel), METH_NOARGS},
    {"msleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_msleep), METH_O|METH_STATIC},
    {"priority", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_priority), METH_NOARGS},
    {"quit", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_quit), METH_NOARGS},
    {"requestInterruption", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_requestInterruption), METH_NOARGS},
    {"run", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_run), METH_NOARGS},
    {"setEventDispatcher", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setEventDispatcher), METH_O},
    {"setPriority", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setPriority), METH_O},
    {"setStackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setStackSize), METH_O},
    {"setTerminationEnabled", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_setTerminationEnabled), METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"sleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_sleep), METH_O|METH_STATIC},
    {"stackSize", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_stackSize), METH_NOARGS},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_start), METH_VARARGS|METH_KEYWORDS},
    {"terminate", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_terminate), METH_NOARGS},
    {"usleep", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_usleep), METH_O|METH_STATIC},
    {"wait", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_wait), METH_VARARGS|METH_KEYWORDS},
    {"yieldCurrentThread", reinterpret_cast<PyCFunction>(Sbk_QThreadFunc_yieldCurrentThread), METH_NOARGS|METH_STATIC},

    {nullptr, nullptr} // Sentinel
};

static int Sbk_QThread_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    if (value && PyCallable_Check(value)) {
        auto plain_inst = reinterpret_cast< ::QThread *>(Shiboken::Conversions::cppPointer(SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX], reinterpret_cast<SbkObject *>(self)));
        auto inst = dynamic_cast<QThreadWrapper *>(plain_inst);
        if (inst)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QThread_traverse(PyObject *self, visitproc visit, void *arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_QThread_clear(PyObject *self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_QThread_Type = nullptr;
static SbkObjectType *Sbk_QThread_TypeF(void)
{
    return _Sbk_QThread_Type;
}

static PyType_Slot Sbk_QThread_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QThread_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QThread_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QThread_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QThread_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QThread_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_QThread_spec = {
    "2:PySide2.QtCore.QThread",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_QThread_slots
};

} //extern "C"

static void *Sbk_QThread_typeDiscovery(void *cptr, SbkObjectType *instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType *>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QThread *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QThread_Priority_PythonToCpp_QThread_Priority(PyObject *pyIn, void *cppOut) {
    *reinterpret_cast<::QThread::Priority *>(cppOut) =
        static_cast<::QThread::Priority>(Shiboken::Enum::getValue(pyIn));

}
static PythonToCppFunc is_QThread_Priority_PythonToCpp_QThread_Priority_Convertible(PyObject *pyIn) {
    if (PyObject_TypeCheck(pyIn, SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX]))
        return QThread_Priority_PythonToCpp_QThread_Priority;
    return {};
}
static PyObject *QThread_Priority_CppToPython_QThread_Priority(const void *cppIn) {
    const int castCppIn = int(*reinterpret_cast<const ::QThread::Priority *>(cppIn));
    return Shiboken::Enum::newItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX], castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QThread_PythonToCpp_QThread_PTR(PyObject *pyIn, void *cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_QThread_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QThread_PythonToCpp_QThread_PTR_Convertible(PyObject *pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject *>(Sbk_QThread_TypeF())))
        return QThread_PythonToCpp_QThread_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QThread_PTR_CppToPython_QThread(const void *cppIn) {
    return PySide::getWrapperForQObject(reinterpret_cast<::QThread *>(const_cast<void *>(cppIn)), Sbk_QThread_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QThread_SignatureStrings[] = {
    R"CPP(PySide2.QtCore.QThread(parent:PySide2.QtCore.QObject=nullptr))CPP",
    R"CPP(PySide2.QtCore.QThread.currentThread()->PySide2.QtCore.QThread)CPP",
    R"CPP(PySide2.QtCore.QThread.event(event:PySide2.QtCore.QEvent)->bool)CPP",
    R"CPP(PySide2.QtCore.QThread.eventDispatcher()->PySide2.QtCore.QAbstractEventDispatcher)CPP",
    R"CPP(PySide2.QtCore.QThread.exec_()->int)CPP",
    R"CPP(PySide2.QtCore.QThread.exit(retcode:int=0))CPP",
    R"CPP(PySide2.QtCore.QThread.idealThreadCount()->int)CPP",
    R"CPP(PySide2.QtCore.QThread.isFinished()->bool)CPP",
    R"CPP(PySide2.QtCore.QThread.isInterruptionRequested()->bool)CPP",
    R"CPP(PySide2.QtCore.QThread.isRunning()->bool)CPP",
    R"CPP(PySide2.QtCore.QThread.loopLevel()->int)CPP",
    R"CPP(PySide2.QtCore.QThread.msleep(arg__1:unsigned long))CPP",
    R"CPP(PySide2.QtCore.QThread.priority()->PySide2.QtCore.QThread.Priority)CPP",
    R"CPP(PySide2.QtCore.QThread.quit())CPP",
    R"CPP(PySide2.QtCore.QThread.requestInterruption())CPP",
    R"CPP(PySide2.QtCore.QThread.run())CPP",
    R"CPP(PySide2.QtCore.QThread.setEventDispatcher(eventDispatcher:PySide2.QtCore.QAbstractEventDispatcher))CPP",
    R"CPP(PySide2.QtCore.QThread.setPriority(priority:PySide2.QtCore.QThread.Priority))CPP",
    R"CPP(PySide2.QtCore.QThread.setStackSize(stackSize:uint))CPP",
    R"CPP(PySide2.QtCore.QThread.setTerminationEnabled(enabled:bool=true))CPP",
    R"CPP(PySide2.QtCore.QThread.sleep(arg__1:unsigned long))CPP",
    R"CPP(PySide2.QtCore.QThread.stackSize()->uint)CPP",
    R"CPP(PySide2.QtCore.QThread.start(priority:PySide2.QtCore.QThread.Priority=InheritPriority))CPP",
    R"CPP(PySide2.QtCore.QThread.terminate())CPP",
    R"CPP(PySide2.QtCore.QThread.usleep(arg__1:unsigned long))CPP",
    R"CPP(1:PySide2.QtCore.QThread.wait(deadline:PySide2.QtCore.QDeadlineTimer=QDeadlineTimer(QDeadlineTimer.Forever))->bool)CPP",
    R"CPP(0:PySide2.QtCore.QThread.wait(time:unsigned long)->bool)CPP",
    R"CPP(PySide2.QtCore.QThread.yieldCurrentThread())CPP",
    nullptr}; // Sentinel

void init_QThread(PyObject *module)
{
    _Sbk_QThread_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QThread",
        "QThread*",
        &Sbk_QThread_spec,
        QThread_SignatureStrings,
        &Shiboken::callCppDestructor< ::QThread >,
        reinterpret_cast<SbkObjectType *>(SbkPySide2_QtCoreTypes[SBK_QOBJECT_IDX]),
        0,
        0    );
    
    SbkPySide2_QtCoreTypes[SBK_QTHREAD_IDX]
        = reinterpret_cast<PyTypeObject *>(Sbk_QThread_TypeF());

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(Sbk_QThread_TypeF(),
        QThread_PythonToCpp_QThread_PTR,
        is_QThread_PythonToCpp_QThread_PTR_Convertible,
        QThread_PTR_CppToPython_QThread);

    Shiboken::Conversions::registerConverterName(converter, "QThread");
    Shiboken::Conversions::registerConverterName(converter, "QThread*");
    Shiboken::Conversions::registerConverterName(converter, "QThread&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QThread).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::QThreadWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_QThread_TypeF(), &Sbk_QThread_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'Priority'.
    SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX] = Shiboken::Enum::createScopedEnum(Sbk_QThread_TypeF(),
        "Priority",
        "2:PySide2.QtCore.QThread.Priority",
        "QThread::Priority");
    if (!SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX])
        return;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "IdlePriority", (long) QThread::Priority::IdlePriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "LowestPriority", (long) QThread::Priority::LowestPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "LowPriority", (long) QThread::Priority::LowPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "NormalPriority", (long) QThread::Priority::NormalPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "HighPriority", (long) QThread::Priority::HighPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "HighestPriority", (long) QThread::Priority::HighestPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "TimeCriticalPriority", (long) QThread::Priority::TimeCriticalPriority))
        return;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
        Sbk_QThread_TypeF(), "InheritPriority", (long) QThread::Priority::InheritPriority))
        return;
    // Register converter for enum 'QThread::Priority'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX],
            QThread_Priority_CppToPython_QThread_Priority);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QThread_Priority_PythonToCpp_QThread_Priority,
            is_QThread_Priority_PythonToCpp_QThread_Priority_Convertible);
        Shiboken::Enum::setTypeConverter(SbkPySide2_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX], converter);
        Shiboken::Conversions::registerConverterName(converter, "QThread::Priority");
        Shiboken::Conversions::registerConverterName(converter, "Priority");
    }
    // End of 'Priority' enum.

    PySide::Signal::registerSignals(Sbk_QThread_TypeF(), &::QThread::staticMetaObject);

    qRegisterMetaType< ::QThread::Priority >("QThread::Priority");
    Shiboken::ObjectType::setSubTypeInitHook(Sbk_QThread_TypeF(), &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(Sbk_QThread_TypeF(), &::QThread::staticMetaObject, sizeof(QThreadWrapper));
}
